@@ -23,25 +23,25 @@
 
 #include "webview.h"
 #include "webpage.h"
+#include "kwebkitpart_debug.h"
 #include "kwebkitpart.h"
 #include "settings/webkitsettings.h"
 
 #include <kio/global.h>
-#include <KDE/KAboutData>
-#include <KDE/KAction>
-#include <KDE/KActionCollection>
-#include <KDE/KConfigGroup>
-#include <KDE/KMimeType>
-#include <KDE/KService>
-#include <KDE/KUriFilter>
-#include <KDE/KStandardDirs>
-#include <KDE/KActionMenu>
-#include <KDE/KIO/AccessManager>
-#include <KDE/KStringHandler>
-#include <KDE/KDebug>
-#include <KDE/KLocalizedString>
-#include <KDE/KIcon>
+#include <KAboutData>
+#include <KAction>
+#include <KActionCollection>
+#include <KConfigGroup>
+#include <KMimeType>
+#include <KService>
+#include <KUriFilter>
 
+#include <KActionMenu>
+#include <KIO/AccessManager>
+#include <KStringHandler>
+#include <KLocalizedString>
+
+#include <QIcon>
 #include <QTimer>
 #include <QMimeData>
 #include <QDropEvent>
@@ -86,7 +86,7 @@ WebView::WebView(KWebKitPart* part, QWidget* parent)
 
 WebView::~WebView()
 {
-    //kDebug();
+    //qCDebug(KWEBKITPART_LOG);
 }
 
 void WebView::loadUrl(const QUrl& url, const KParts::OpenUrlArguments& args, const KParts::BrowserArguments& bargs)
@@ -299,7 +299,7 @@ void WebView::keyPressEvent(QKeyEvent* e)
                 break;
             }
         } else if (m_autoScrollTimerId != -1) {
-            // kDebug() << "scroll timer id:" << m_autoScrollTimerId;
+            // qCDebug(KWEBKITPART_LOG) << "scroll timer id:" << m_autoScrollTimerId;
             slotStopAutoScroll();
             e->accept();
             return;
@@ -533,7 +533,7 @@ void WebView::partActionPopupMenu(KParts::BrowserExtension::ActionGroupMap& part
     } else if (m_result.frame() && m_result.frame()->parentFrame() && !m_result.isContentSelected() && m_result.linkUrl().isEmpty()) {
         KActionMenu * menu = new KActionMenu(i18nc("@title:menu HTML frame/iframe", "Frame"), this);
 
-        QAction* action = new QAction(KIcon("window-new"), i18n("Open in New &Window"), this);
+        QAction* action = new QAction(QIcon::fromTheme(QStringLiteral("window-new")), i18n("Open in New &Window"), this);
         m_actionCollection->addAction(QL1S("frameinwindow"), action);
         connect(action, SIGNAL(triggered(bool)), m_part->browserExtension(), SLOT(slotFrameInWindow()));
         menu->addAction(action);
@@ -543,7 +543,7 @@ void WebView::partActionPopupMenu(KParts::BrowserExtension::ActionGroupMap& part
         connect(action, SIGNAL(triggered(bool)), m_part->browserExtension(), SLOT(slotFrameInTop()));
         menu->addAction(action);
 
-        action = new QAction(KIcon("tab-new"), i18n("Open in &New Tab"), this);
+        action = new QAction(QIcon::fromTheme(QStringLiteral("tab-new")), i18n("Open in &New Tab"), this);
         m_actionCollection->addAction(QL1S("frameintab"), action);
         connect(action, SIGNAL(triggered(bool)), m_part->browserExtension(), SLOT(slotFrameInTab()));
         menu->addAction(action);
@@ -557,7 +557,7 @@ void WebView::partActionPopupMenu(KParts::BrowserExtension::ActionGroupMap& part
         connect(action, SIGNAL(triggered(bool)), m_part->browserExtension(), SLOT(slotReloadFrame()));
         menu->addAction(action);
 
-        action = new QAction(KIcon("document-print-frame"), i18n("Print Frame..."), this);
+        action = new QAction(QIcon::fromTheme(QStringLiteral("document-print-frame")), i18n("Print Frame..."), this);
         m_actionCollection->addAction(QL1S("printFrame"), action);
         connect(action, SIGNAL(triggered(bool)), m_part->browserExtension(), SLOT(print()));
         menu->addAction(action);
@@ -636,7 +636,7 @@ void WebView::selectActionPopupMenu(KParts::BrowserExtension::ActionGroupMap& se
     data.setCheckForExecutables(false);
     if (KUriFilter::self()->filterUri(data, QStringList() << "kshorturifilter" << "fixhosturifilter") &&
         data.uri().isValid() && data.uriType() == KUriFilterData::NetProtocol) {
-        QAction *action = new QAction(KIcon("window-new"), i18nc("open selected url", "Open '%1'",
+        QAction *action = new QAction(QIcon::fromTheme(QStringLiteral("window-new")), i18nc("open selected url", "Open '%1'",
                                             KStringHandler::rsqueeze(data.uri().url(), 18)), this);
         m_actionCollection->addAction(QL1S("openSelection"), action);
         action->setData(QUrl(data.uri()));
@@ -671,7 +671,7 @@ void WebView::linkActionPopupMenu(KParts::BrowserExtension::ActionGroupMap& link
         linkActions.append(action);
     } else {
         if (!m_result.isContentSelected()) {
-            action = new QAction(KIcon("edit-copy"), i18n("Copy Link &Text"), this);
+            action = new QAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy Link &Text"), this);
             m_actionCollection->addAction(QL1S("copylinktext"), action);
             connect(action, SIGNAL(triggered(bool)), m_part->browserExtension(), SLOT(slotCopyLinkText()));
             linkActions.append(action);
@@ -783,7 +783,7 @@ void WebView::addSearchActions(QList<QAction*>& selectActions, QWebView* view)
 
     if (KUriFilter::self()->filterSearchUri(data, KUriFilter::NormalTextFilter)) {
         const QString squeezedText = KStringHandler::rsqueeze(selectedText, 20);
-        QAction *action = new QAction(KIcon(data.iconName()),
+        QAction *action = new QAction(QIcon::fromTheme(data.iconName()),
                                       i18nc("Search \"search provider\" for \"text\"", "Search %1 for '%2'",
                                             data.searchProvider(), squeezedText), view);
         action->setData(QUrl(data.uri()));
@@ -800,7 +800,7 @@ void WebView::addSearchActions(QList<QAction*>& selectActions, QWebView* view)
                 if (searchProvider == data.searchProvider())
                     continue;
 
-                QAction *action = new QAction(KIcon(data.iconNameForPreferredSearchProvider(searchProvider)), searchProvider, view);
+                QAction *action = new QAction(QIcon::fromTheme(data.iconNameForPreferredSearchProvider(searchProvider)), searchProvider, view);
                 action->setData(data.queryForPreferredSearchProvider(searchProvider));
                 m_actionCollection->addAction(searchProvider, action);
                 connect(action, SIGNAL(triggered(bool)), m_part->browserExtension(), SLOT(searchProvider()));
@@ -876,9 +876,9 @@ static void handleDuplicateLinkElements(const QWebElement& element, QHash<QStrin
 {
     if (element.tagName().compare(QL1S("A"), Qt::CaseInsensitive) == 0) {
         const QString linkKey (linkElementKey(element));
-        // kDebug() << "LINK KEY:" << linkKey;
+        // qCDebug(KWEBKITPART_LOG) << "LINK KEY:" << linkKey;
         if (dupLinkList->contains(linkKey)) {
-            // kDebug() << "***** Found duplicate link element:" << linkKey << endl;
+            // qCDebug(KWEBKITPART_LOG) << "***** Found duplicate link element:" << linkKey << endl;
             *accessKey = dupLinkList->value(linkKey);
         } else if (!linkKey.isEmpty()) {
             dupLinkList->insert(linkKey, *accessKey);
